@@ -9,19 +9,25 @@ our $VERSION = 0.01;
 our @ISA     = qw(Exporter);
 our @EXPORT  = qw(
                   for_all_hosts
-                  get_filepath_current
-                  get_hostclass
-                  get_site
-                  get_sitegroup
-                  get_hostname
-                  get_dns_address
-                  get_macaddresses
-                  get_primary_macaddress
-                  get_primary_ip_address
-                  get_linux_kernel_ver
+                  get_age_group
+                  get_age_groups
                   get_debian_edu_profile
                   get_debian_edu_ver
+                  get_debian_ver
+                  get_default_route
+                  get_dns_address
+                  get_filepath_current
                   get_hardware_info
+                  get_hostclass
+                  get_hostname
+                  get_linux_kernel_ver
+                  get_macaddresses
+                  get_primary_ip_address
+                  get_primary_macaddress
+                  get_site
+                  get_sitegroup
+                  is_laptop
+                  is_pkg_installed
                   );
 
 my $pwd = "/var/lib/sitesummary/entries";  # Path to the entries
@@ -122,6 +128,22 @@ sub get_macaddresses {
     }
 }
 
+# Return current default route used on host
+sub get_default_route {
+    my $hostid = shift;
+    my $path = get_filepath_current($hostid, "/system/route-n");
+    if (open(my $fh, $path)) {
+        while (<$fh>) {
+            if (m/^0.0.0.0\s+(\S+)\s+/) {
+                close($fh);
+                return $1;
+            }
+        }
+        close($fh);
+    }
+    return undef;
+}
+
 #
 # Return the IP address on the primary network interface
 #
@@ -230,6 +252,19 @@ sub get_debian_edu_ver {
     }
 }
 
+sub get_debian_ver {
+    my $hostid = shift;
+    my $path = get_filepath_current($hostid, "/debian/debian_version");
+    if (open (my $fh, $path)) {
+        my $version = <$fh>;
+        chomp $version;
+        close($fh);
+        return $version;
+    } else {
+        return undef;
+    }
+}
+
 sub get_hardware_info {
     my $hostid = shift;
     my $path = get_filepath_current($hostid, "/system/dmidecode");
@@ -248,12 +283,32 @@ sub get_hardware_info {
         }
         close(FILE);
 
+        # Avoid returning bogus vendor and model
+        undef $vendor if (defined $vendor &&
+                          (
+                           "Not Specified" eq $vendor
+                           || "System Manufaturer" eq $vendor
+                           || "System manufaturer" eq $vendor
+                           || "System manufacturer" eq $vendor
+                           || "To Be Filled By O.E.M." eq $vendor
+                           || "To Be Filled By O.E.M. by More String" eq $vendor
+                          ));
+        undef $model if (defined $model &&
+                         (
+                          "Not Specified" eq $model
+                          || "System Name" eq $model
+                          || "System Product Name" eq $model
+                          || "To Be Filled By O.E.M." eq $model
+                          || "To Be Filled By O.E.M. To Be Filled By O.E.M." eq $model
+                         ));
+
         # Append version string to get for example the thinkpad model
         # name, but ignore bogus entries.
         $model = "$model $version" if ($version
                                        && $version ne "Not Specified"
                                        && $version ne "Not Available"
                                        && $version ne "System Version"
+                                       && $version ne "To Be Filled By O.E.M."
                                        && $version ne "None");
 
         return ($vendor, $model, $serial);
@@ -262,6 +317,28 @@ sub get_hardware_info {
     }
 }
 
+sub is_pkg_installed {
+    my ($hostid, $pkgname) = @_;
+    # Check debian/dpkg-l for 'ii *pkgname '
+    my $path = get_filepath_current($hostid, "/debian/dpkg-l");
+    if (open (my $fh, $path)) {
+        while(<$fh>) {
+            if (m/^ii *$pkgname /) {
+                close($fh);
+                return 1
+            }
+        }
+        close($fh);
+    }
+    return undef;
+}
+
+sub is_laptop {
+    my $hostid = shift;
+    my $path = get_filepath_current($hostid, "/system/laptop");
+    return -e $path;
+}
+
 sub for_all_hosts {
     my $callback = shift;
 
@@ -285,6 +362,33 @@ sub for_all_hosts {
     return $count;
 }
 
+sub get_age_groups {
+    return (
+        0 => '>0 days',
+        3 => '>3 days',
+        7 => '>one week',
+        14 => '>14 days',
+        30 => '>30 days',
+        90 => '>90 days',
+        120 => '>120 days',
+        180 => '>180 days',
+        );
+}
+sub get_age_group {
+    my $hostid = shift;
+    my %agegroups = get_age_groups();
+    my $topdir = get_filepath_current($hostid, "/");
+    my $age = (time() - (stat($topdir))[9]) / (60 * 60 * 24);
+
+    my $thisgroup;
+    for my $group (sort { $a <=> $b; } keys %agegroups) {
+        if ($age > $group) {
+            $thisgroup = $group;
+        }
+    }
+    return $thisgroup;
+}
+
 1;
 
 ########################################################################
